@@ -31,7 +31,8 @@ attr(factors, 'subset') <- NULL
 
 # fitted / residuals must be of the same kind as original cube
 stopifnot(is.null(attr.all.equal(cube, fitted(factors))))
-stopifnot(is.null(attr.all.equal(cube, residuals(factors))))
+# residuals() sets an additional class of feem.resid which only affects plots
+stopifnot(is.null(attr.all.equal(cube, `class<-`(residuals(factors), 'feemcube'))))
 
 # check environment access
 env <- new.env(parent = emptyenv())
